@@ -247,9 +247,14 @@ def readdx(filenames):
         dxfile.close()
         splittext = dxtext.split()
         del splittext[0:splittext.index('follows') + 1]  # get rid of header text, last word is "follows"
-        del splittext[-4:-1]
-        del splittext[-1]  # dont know why i cant just use a 0 instead of -1 above
-        floats = [float(element) for element in splittext]
+        floats = []
+        for element in splittext:
+            if len(element) > 0:
+                try: 
+                    floats.append(float(element))
+                except ValueError:
+                    pass
+        assert len(floats) == gridcount[0]*gridcount[1]*gridcount[2]
         index = 0
         for x in range(gridcount[0]):
             for y in range(gridcount[1]):
